@@ -10,7 +10,7 @@ from ground_soil.fabric import eval_kwargs, virtual_env
 from ground_soil.filesystem import temporary_directory, render_file
 from beanstalk import IDENTIFIER, BEANSTALK_ROOT_PATH
 from beanstalk.decorators import beanstalk_role
-from beanstalk.tasks.utils import load_role_settings as load_beanstalk_settings, set_verbose_level
+from beanstalk.tasks.utils import load_role_settings as load_beanstalk_settings, set_verbose_level, run_hooked_actions
 from beanstalk.titles import tool_title, section_title
 
 
@@ -102,13 +102,8 @@ def setup(settings_path=None, **settings_patches):
             with lcd(uwsgi_src_folder):
                 # Create build configuration
                 local('mkdir -p /usr/local/lib/uwsgi')
-                config = ConfigParser.ConfigParser()
-                config.add_section('uwsgi')
-                config.set('uwsgi', 'main_plugin', 'python')
-                config.set('uwsgi', 'inherit', 'base')
-                config.set('uwsgi', 'plugin_dir', '/usr/local/lib/uwsgi')
-                with open(os.path.join(tmp_directory, uwsgi_src_folder, 'buildconf/beanstalk.ini'), 'w') as f:
-                    config.write(f)
+                uwsgi_build_ini_path = os.path.join(BEANSTALK_ROOT_PATH, 'static/uwsgi_build.ini')
+                local('cp %s buildconf/beanstalk.ini' % uwsgi_build_ini_path)
                 # Build and install
                 local('python uwsgiconfig.py --build beanstalk')
                 local('cp uwsgi /usr/local/bin/uwsgi')
@@ -189,6 +184,11 @@ def setup(settings_path=None, **settings_patches):
     local('chown -R beanstalk:beanstalk %s' % beanstalk_stack_base)
     local('/etc/init.d/sshd restart')
     local('/etc/init.d/httpd restart')
+    local('/etc/init.d/beanstalk start')
+    local('chkconfig beanstalk on')
+
+    # Call post-install script
+    run_hooked_actions('POST_INSTALLATION_ACTIONS')
 
 
 @task
@@ -318,8 +318,8 @@ def delete_app(project_name, settings_path=None, **settings_patches):
 
 @task
 @beanstalk_role('server')
-def update_app(project_name, settings_path=None, **settings_patches):
-    """Update an app (call when u updated the code)
+def install_app(project_name, settings_path=None, **settings_patches):
+    """Install an app (call when u updated the code)
     """
     settings_patches = eval_kwargs(settings_patches)
     load_beanstalk_settings(local_settings_path=settings_path, **settings_patches)
